@@ -29,19 +29,20 @@ class NMState(Resource):
             affinity (dict[str, Any]): Affinity is an optional affinity selector that will be added to
               handler DaemonSet manifest.
 
-            infra_affinity (dict[str, Any]): Affinity is an optional affinity selector that will be added to
-              webhook & certmanager Deployment manifests.
+            infra_affinity (dict[str, Any]): InfraAffinity is an optional affinity selector that will be added to
+              webhook, metrics & console-plugin Deployment manifests.
 
             infra_node_selector (dict[str, Any]): InfraNodeSelector is an optional selector that will be added to
-              webhook & certmanager Deployment manifests If InfraNodeSelector is
-              specified, the webhook and certmanager will run only on nodes that
-              have each of the indicated key-value pairs as labels applied to
-              the node.
+              webhook, metrics & console-plugin Deployment manifests If
+              InfraNodeSelector is specified, the webhook, metrics and the
+              console plugin will run only on nodes that have each of the
+              indicated key-value pairs as labels applied to the node.
 
             infra_tolerations (list[Any]): InfraTolerations is an optional list of tolerations to be added to
-              webhook & certmanager Deployment manifests If InfraTolerations is
-              specified, the webhook and certmanager will be able to be
-              scheduled on nodes with corresponding taints
+              webhook, metrics & console-plugin Deployment manifests If
+              InfraTolerations is specified, the webhook, metrics and the
+              console plugin will be able to be scheduled on nodes with
+              corresponding taints
 
             node_selector (dict[str, Any]): NodeSelector is an optional selector that will be added to handler
               DaemonSet manifest for both workers and control-plane
